<?php

namespace Drupal\imago\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for the Article candidate module.
 */
class ImagoSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['imago.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'imago_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('imago.settings');

    $form = [
      '#type' => 'details',
      '#title' => t('Imago API settings.', [], ['context' => 'imago']),
      '#open' => TRUE,
      '#tree' => TRUE,
    ];
    $form['api'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('API settings'),
      '#description' => $this->t('The name used to indicate anonymous users.'),
    ];
    $form['api']['api_url'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Search'),
    ];
    $form['api']['api_url']['base_url'] = [
      '#title' => $this->t('Base API URL.', [], ['context' => 'imago']),
      '#type' => 'textfield',
      '#size' => 60,
      '#default_value' => ($config->get('api')['api_url']['base_url']) ?? NULL,
      '#description' => $this->t('The base API URL.'),
      '#placeholder' => 'https://API-URL.imago-images.de',
      '#required' => TRUE,
    ];
    $form['api']['api_url']['search_url'] = [
      '#title' => $this->t('Search API URL.', [], ['context' => 'imago']),
      '#type' => 'textfield',
      '#size' => 60,
      '#default_value' => ($config->get('api')['api_url']['search_url']) ?? NULL,
      '#description' => $this->t('Full API url for search service. Replace API-URL by your credentials.'),
      '#placeholder' => 'https://API-URL.imago-images.de/search',
      '#required' => TRUE,
    ];
    $form['api']['api_url']['download_url'] = [
      '#title' => $this->t('Download API URL.', [], ['context' => 'imago']),
      '#type' => 'textfield',
      '#size' => 60,
      '#default_value' => ($config->get('api')['api_url']['download_url']) ?? NULL,
      '#description' => $this->t('Full API url for download. Replace API-URL by your credentials.'),
      '#placeholder' => 'https://API-URL.imago-images.de/download',
      '#required' => TRUE,
    ];
    $form['api']['api_user'] = [
      '#title' => $this->t('API user.', [], ['context' => 'imago']),
      '#type' => 'textfield',
      '#size' => 60,
      '#default_value' => ($config->get('api')['api_user']) ?? NULL,
      '#description' => $this->t('Your Imago API-USER-NAME.'),
      '#required' => TRUE,
    ];
    $form['api']['api_key'] = [
      '#title' => $this->t('API key', [], ['context' => 'imago']),
      '#type' => 'password',
      '#size' => 60,
      '#default_value' => ($config->get('api')['api_key']) ?? NULL,
      '#description' => $this->t('Your Imago API-KEY.'),
      '#required' => TRUE,
    ];
    $media_types = $types = \Drupal::entityTypeManager()->getStorage('media_type')->loadMultiple();
    $options = [];
    foreach ($media_types as $media_type) {
      $options[$media_type->id()] = $media_type->label();
    }
    $form['media'] = [
      '#type' => 'select',
      '#title' => $this->t('Allowed media'),
      '#options' => $options,
      '#default_value' => ($config->get('media')) ?? NULL,
      '#description' => $this->t('Media entity where will be image imported.'),
      '#required' => TRUE,
    ];
    $resolution = [
      1 => 'Thumbnail 192px',
      2 => 'Small 420px',
      4 => 'Medium w/ watermark 1000px',
      8 => 'Medium w/o watermark 1000px',
      9 => 'High > 1000px',
    ];
    $form['resolution'] = [
      '#type' => 'select',
      '#title' => $this->t('Picture resolution'),
      '#options' => $resolution,
      '#default_value' => ($config->get('resolution')) ?? NULL,
      '#description' => $this->t('Resolution have to correspond to your PHP max upload size.'),
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('imago.settings');
    $api = $form_state->getValue('api');
    $media = $form_state->getValue('media');
    $resolution = $form_state->getValue('resolution');
    if (empty($api['api_key'])) {
      $api['api_key'] = $config->get('api')['api_key'];
    }

    $this->config('imago.settings')
      ->set('api', $api)
      ->set('media', $media)
      ->set('resolution', $resolution)
      ->save();
    parent::submitForm($form, $form_state);
  }

}
